@@ -14,6 +14,7 @@ def test_help():
     cmd = """sequana_pipelines_demultiplex --help"""
     subprocess.call(cmd.split())
 
+
 def test_standalone_subprocess(tmp_path):
     directory = tmp_path / "test"
     directory.mkdir()
@@ -21,7 +22,7 @@ def test_standalone_subprocess(tmp_path):
     with tempfile.TemporaryDirectory() as directory:
         cmd = """sequana_pipelines_demultiplex --bcl-directory {} """
         cmd += """--run-mode local --working-directory {} --force --sample-sheet {} --merging-strategy none"""
-        cmd = cmd.format(sharedir, directory, samplesheet)
+        cmd = cmd.format(sharedir +"/bcl", directory, samplesheet)
         subprocess.call(cmd.split())
 
 
@@ -29,7 +30,7 @@ def test_standalone_script(tmp_path):
     directory = tmp_path / "test"
     directory.mkdir()
     import sequana_pipelines.demultiplex.main as m
-    sys.argv = ["test", "--bcl-directory", sharedir, "--merging-strategy", "merge",
+    sys.argv = ["test", "--bcl-directory", sharedir+"/bcl", "--merging-strategy", "merge",
           "--working-directory", str(directory), "--force", "--sample-sheet", samplesheet]
     m.main()
 
@@ -41,6 +42,6 @@ def test_standalone_baddies(tmp_path):
     with tempfile.TemporaryDirectory() as directory:
         cmd = """sequana_pipelines_demultiplex --bcl-directory {} """
         cmd += """--run-mode local --working-directory {} --force --sample-sheet {} --merging-strategy none"""
-        cmd = cmd.format(sharedir, directory, "wrong")
+        cmd = cmd.format(sharedir + "/bcl", directory, "wrong")
         subprocess.call(cmd.split())
 
